@@ -4,8 +4,6 @@ use warnings;
 use Data::Dumper;
 use overload (
               "0+"     => sub { "\"${$_[0]}\""; },
-              "++"     => sub { $_[0] = ${$_[0]} + 1 },
-              "--"     => sub { $_[0] = ${$_[0]} - 1 },
               '""'     => sub { ${$_[0]}},
               "."      => sub { ${$_[0]}},
               "eq"     => sub { ${$_[0]} },
